@@ -113,11 +113,10 @@ checkpointLoad <- function(file) {
   assign(.objectNames("spades", "simList", "sim")[[1]]$objs, sim, envir = tmpEnv)
 
   if (file.exists(file[1])) {
-    if (length(file) > 1) browser()
     unlink(file)
   }
   saveSimList(.objectNames("spades", "simList", "sim")[[1]]$objs,
-              filename = file, envir = tmpEnv)
+              filename = file, envir = tmpEnv, paths = paths(sim))
 
   invisible(TRUE) # return "success" invisibly
 }
