@@ -1,8 +1,5 @@
 test_that("misc tests", {
-  testInitOut <- testInit(smcc = FALSE, debug = FALSE)
-  on.exit({
-    testOnExit(testInitOut)
-  }, add = TRUE)
+  testInit(smcc = FALSE, debug = FALSE)
 
   expect_error(needInstall("httr2", minVersion = "1.4.1"), "is required")
   expect_error(needInstall("httr", minVersion = "100000.4.1"), "httr\\(>=")
@@ -11,10 +8,7 @@ test_that("misc tests", {
 })
 
 test_that(".emptyEventList tests", {
-  testInitOut <- testInit(smcc = FALSE, libraries = "data.table")
-  on.exit({
-    testOnExit(testInitOut)
-  }, add = TRUE)
+  testInit(smcc = FALSE, libraries = "data.table")
   a <- .emptyEventList()
   expect_true(is(a, "data.table"))
   b <- .emptyEventList(1, "a", "b", 5)
@@ -27,10 +21,7 @@ test_that(".emptyEventList tests", {
 })
 
 test_that("modify search path", {
-  testInitOut <- testInit(smcc = FALSE, "fastdigest")
-  on.exit({
-    testOnExit(testInitOut)
-  }, add = TRUE)
+  testInit(smcc = FALSE)
 
   pkgToAttach <- "crayon"
   spPre <- search()
@@ -47,17 +38,14 @@ test_that("modify search path", {
   a <- .modifySearchPath(pkgs = pkgToAttach, removeOthers = TRUE, skipNamespacing = FALSE)
   spPost <- search()
   expect_true(any(grep(pkgToAttach[1], spPost) == 2L))
-  expect_true(identical(grep("fastdigest", spPost), integer()))
+  expect_true(identical(grep("digest", spPost), integer()))
   detach("package:crayon")
   spPost2 <- search()
   expect_false(any(grep(pkgToAttach[1], spPost2) == 2L))
 })
 
 test_that("test all.equal.simList", {
-  testInitOut <- testInit(smcc = FALSE, "fastdigest")
-  on.exit({
-    testOnExit(testInitOut)
-  }, add = TRUE)
+  testInit(smcc = FALSE, "digest")
 
   s1 <- simInit()
   s2 <- simInit()
@@ -71,3 +59,4 @@ test_that("test all.equal.simList", {
   expect_true(all.equal(a1, b1))
   expect_true(all.equal(a2, b2))
 })
+
